@@ -2,8 +2,9 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Author;
 # ABSTRACT: An Author data object
-$MetaCPAN::Client::Author::VERSION = '2.011000';
+$MetaCPAN::Client::Author::VERSION = '2.012000';
 use Moo;
+use Ref::Util qw< is_arrayref >;
 
 with 'MetaCPAN::Client::Role::Entity';
 
@@ -36,6 +37,16 @@ my %known_fields = (
     >],
 );
 
+sub BUILDARGS {
+    my ( $class, %args ) = @_;
+
+    my $email = $args{'email'} || [];
+    $args{'email'} = [ $email ]
+        unless is_arrayref($email);
+
+    return \%args;
+}
+
 my @known_fields =
     map { @{ $known_fields{$_} } } qw< scalar arrayref hashref >;
 
@@ -82,7 +93,7 @@ MetaCPAN::Client::Author - An Author data object
 
 =head1 VERSION
 
-version 2.011000
+version 2.012000
 
 =head1 SYNOPSIS
 
@@ -262,6 +273,10 @@ by author.
 
 =head1 METHODS
 
+=head2 BUILDARGS
+
+Ensures format of the input.
+
 =head2 releases
 
     my $releases = $author->releases();
